# -*- coding: utf-8 -*-
#
# GNU General Public License (GPL)
#

from imio.history.adapters import BaseImioHistoryAdapter
from Products.CMFCore.permissions import DeleteObjects
from Products.CMFCore.utils import _checkPermission


class ContentDeletableAdapter(object):
    """
      Manage the mayDelete on every objects.
    """

    def __init__(self, context):
        self.context = context

    def mayDelete(self, **kwargs):
        '''See docstring in interfaces.py'''
        return _checkPermission(DeleteObjects, self.context)


class DeletedChildrenHistoryAdapter(BaseImioHistoryAdapter):
    """ """

    history_type = 'deleted_children'
    history_attr_name = 'deleted_children_history'
    highlight_last_comment = True



# -*- coding: utf-8 -*-
from plone.app.testing import FunctionalTesting
from plone.app.testing import PloneWithPackageLayer
from plone.testing import z2
from plone.testing import zca

import imio.actionspanel


ACTIONSPANEL_ZCML = zca.ZCMLSandbox(filename="testing.zcml",
                                    package=imio.actionspanel,
                                    name='ACTIONSPANEL_ZCML')

ACTIONSPANEL_Z2 = z2.IntegrationTesting(bases=(z2.STARTUP, ACTIONSPANEL_ZCML),
                                        name='ACTIONSPANEL_Z2')

ACTIONSPANEL_TESTING_PROFILE = PloneWithPackageLayer(
    zcml_filename="testing.zcml",
    zcml_package=imio.actionspanel,
    additional_z2_products=(),
    name="ACTIONSPANEL_TESTING_PROFILE")

ACTIONSPANEL_TESTING_PROFILE_FUNCTIONAL = FunctionalTesting(
    bases=(ACTIONSPANEL_TESTING_PROFILE,), name="ACTIONSPANEL_TESTING_PROFILE_FUNCTIONAL")



# -*- coding: utf-8 -*-
#
# GNU General Public License (GPL)
#

from AccessControl import Unauthorized
from appy.gen import No
from imio.actionspanel.interfaces import IContentDeletable


DEFAULT_MAY_NOT_DELETE_MSG = "You can not delete this element!"


def onObjWillBeRemoved(obj, event):
    """
      Called when any object removed to check for ContentDeletable.mayDelete.
    """

    # If we are trying to remove the whole Plone Site bypass
    if event.object.meta_type in ['Plone Site']:
        return

    may_delete = IContentDeletable(obj).mayDelete()
    if not may_delete:
        raise Unauthorized(
            may_delete.msg if isinstance(may_delete, No) else DEFAULT_MAY_NOT_DELETE_MSG)



from plone.app.layout.viewlets import ViewletBase
from zope.component import getMultiAdapter


class ActionsPanelViewlet(ViewletBase):
    '''This viewlet displays the available actions on the context.'''

    async = False
    params = {
        'useIcons': False,
        'showEdit': False
    }

    def show(self):
        """Will we show the viewlet on context?"""
        context_state = getMultiAdapter(
            (self.context, self.request), name=u'plone_context_state')
        return context_state.is_view_template() and 'ajax_load' not in self.request

    def renderViewlet(self):
        """Render the view @@actions_panel that display relevant actions.
           Here we want to display elements with full space, so not as icons."""
        if self.show():
            return self.context.restrictedTraverse(
                "@@actions_panel")(**self.params)



# -*- coding: utf-8 -*-
from zope.interface import Interface
from zope.publisher.interfaces.browser import IBrowserRequest


class IActionsPanelLayer(IBrowserRequest):
    """
      Define a layer so some elements are only added for it
    """


class IContentDeletable(Interface):
    """
      Adapter interface that manage if a particular content is deletable.
    """

    def mayDelete(context):
        """
          This method returns True if current context is deletable.
          The default implementation does the work for checking 'Delete objects' on the
          object we want to delete, not that permission on the parent.
          You can return a appy.gen.No instance to be able to display a message
          why element is not deletable.
        """


class IFolderContentsShowableMarker(Interface):
    """
        Marker that can be used to show folder_contents action
    """
